@@ -9,6 +9,7 @@
 //! available.
 use proc_macro::Ident;
 use quote::ToTokens;
+use syn;
 
 use once_cell::sync::Lazy;
 
@@ -21,10 +22,8 @@ use crate::enum_dispatch_item;
 // structures.
 static TRAIT_DEFS: Lazy<Mutex<HashMap<String, String>>> = Lazy::new(|| Mutex::new(HashMap::new()));
 static ENUM_DEFS: Lazy<Mutex<HashMap<String, String>>> = Lazy::new(|| Mutex::new(HashMap::new()));
-static DEFERRED_LINKS: Lazy<Mutex<HashMap<String, Vec<String>>>> =
-    Lazy::new(|| Mutex::new(HashMap::new()));
-static ENUM_CONVERSION_IMPLS_DEFS: Lazy<Mutex<HashSet<String>>> =
-    Lazy::new(|| Mutex::new(HashSet::new()));
+static DEFERRED_LINKS: Lazy<Mutex<HashMap<String, Vec<String>>>> = Lazy::new(|| Mutex::new(HashMap::new()));
+static ENUM_CONVERSION_IMPLS_DEFS: Lazy<Mutex<HashSet<String>>> = Lazy::new(|| Mutex::new(HashSet::new()));
 
 /// Store a trait definition for future reference.
 pub fn cache_trait(item: syn::ItemTrait) {
@@ -56,10 +55,7 @@ pub fn defer_link(needed: &Ident, cached: &::proc_macro2::Ident) {
     let (needed, cached) = (needed.to_string(), cached.to_string());
     let mut deferred_links = DEFERRED_LINKS.lock().unwrap();
     if deferred_links.contains_key(&needed) {
-        deferred_links
-            .get_mut(&needed)
-            .unwrap()
-            .push(cached.to_owned());
+        deferred_links.get_mut(&needed).unwrap().push(cached.to_owned());
     } else {
         deferred_links.insert(needed.to_owned(), vec![cached.to_owned()]);
     }
@@ -73,53 +69,34 @@ pub fn defer_link(needed: &Ident, cached: &::proc_macro2::Ident) {
 /// Returns a list of all of the trait definitions that were previously linked to the supplied enum
 /// name.
 pub fn fulfilled_by_enum(defname: &::proc_macro2::Ident) -> Vec<syn::ItemTrait> {
-    let idents = match DEFERRED_LINKS
-        .lock()
-        .unwrap()
-        .remove_entry(&defname.to_string())
-    {
+    let idents = match DEFERRED_LINKS.lock().unwrap().remove_entry(&defname.to_string()) {
         Some((_, links)) => links,
         None => vec![],
     };
-    idents
-        .iter()
-        .filter_map(
-            |ident_string| match TRAIT_DEFS.lock().unwrap().get(ident_string) {
-                Some(entry) => Some(syn::parse(entry.parse().unwrap()).unwrap()),
-                None => None,
-            },
-        )
-        .collect()
+    idents.iter().filter_map(|ident_string| {
+        match TRAIT_DEFS.lock().unwrap().get(ident_string) {
+            Some(entry) => Some(syn::parse(entry.parse().unwrap()).unwrap()),
+            None => None,
+        }
+    }).collect()
 }
 
 /// Returns a list of all of the enum definitions that were previously linked to the supplied trait
 /// name.
-pub fn fulfilled_by_trait(
-    defname: &::proc_macro2::Ident,
-) -> Vec<enum_dispatch_item::EnumDispatchItem> {
-    let idents = match DEFERRED_LINKS
-        .lock()
-        .unwrap()
-        .remove_entry(&defname.to_string())
-    {
+pub fn fulfilled_by_trait(defname: &::proc_macro2::Ident) -> Vec<enum_dispatch_item::EnumDispatchItem> {
+    let idents = match DEFERRED_LINKS.lock().unwrap().remove_entry(&defname.to_string()) {
         Some((_, links)) => links,
         None => vec![],
     };
-    idents
-        .iter()
-        .filter_map(
-            |ident_string| match ENUM_DEFS.lock().unwrap().get(ident_string) {
-                Some(entry) => Some(syn::parse(entry.parse().unwrap()).unwrap()),
-                None => None,
-            },
-        )
-        .collect()
+    idents.iter().filter_map(|ident_string| {
+        match ENUM_DEFS.lock().unwrap().get(ident_string) {
+            Some(entry) => Some(syn::parse(entry.parse().unwrap()).unwrap()),
+            None => None,
+        }
+    }).collect()
 }
 
 /// Returns true if From/TryInto was already defined for this enum
 pub fn conversion_impls_def_by_enum(item: &syn::Ident) -> bool {
-    ENUM_CONVERSION_IMPLS_DEFS
-        .lock()
-        .unwrap()
-        .contains(&item.to_string())
+    ENUM_CONVERSION_IMPLS_DEFS.lock().unwrap().contains(&item.to_string())
 }
